@@ -166,7 +166,17 @@ class AiTrilApp {
 
     selectDeploymentTarget(targetId) {
         console.log('Selected deployment target:', targetId);
-        // TODO: Send selection to backend and handle deployment config collection
+
+        // Send deployment selection to backend
+        if (this.ws && this.ws.readyState === WebSocket.OPEN) {
+            this.ws.send(JSON.stringify({
+                type: 'deployment_selected',
+                target: targetId
+            }));
+
+            // Show status message
+            this.addStatusMessage(`🚀 Deploying to ${targetId}...`);
+        }
     }
 
     setupEventListeners() {
@@ -540,6 +550,9 @@ class AiTrilApp {
                             <button class="info-btn" data-mode="consensus" title="Learn about Consensus mode">ⓘ</button>
                         </div>
                     </div>
+                    <button class="settings-btn" onclick="window.app.settings.open()" title="Settings">
+                        ⚙️ Settings
+                    </button>
                 </div>
 
                 <div class="messages-container"></div>
@@ -581,5 +594,7 @@ class AiTrilApp {
 
 // Initialize app when DOM is loaded
 document.addEventListener('DOMContentLoaded', () => {
-    new AiTrilApp();
+    window.app = new AiTrilApp();
+    window.app.settings = new SettingsManager(window.app);
+    window.app.settings.load();
 });
