@@ -17,6 +17,7 @@ from pydantic import BaseModel
 from .config import load_config, load_config_from_env
 from .orchestrator import AiTril
 from .coordinator import CoordinationStrategy
+from .settings import Settings
 
 
 class ChatMessage(BaseModel):
@@ -56,6 +57,9 @@ class ConnectionManager:
 # Global connection manager
 manager = ConnectionManager()
 
+# Global settings manager
+settings_manager = Settings()
+
 # Create FastAPI app
 app = FastAPI(title="AiTril Web Interface")
 
@@ -80,6 +84,7 @@ async def get_index():
     </head>
     <body>
         <div id="app"></div>
+        <script src="/static/settings.js"></script>
         <script src="/static/app.js"></script>
     </body>
     </html>
@@ -115,6 +120,14 @@ async def websocket_endpoint(websocket: WebSocket):
         while True:
             # Receive message from client
             data = await websocket.receive_json()
+
+            # Handle deployment selection messages
+            if data.get("type") == "deployment_selected":
+                target = data.get("target")
+                await handle_deployment(websocket, target)
+                continue
+
+            # Handle regular chat messages
             prompt = data.get("prompt")
             mode = data.get("mode", "tri")
             provider = data.get("provider")
@@ -428,6 +441,155 @@ async def handle_build(websocket: WebSocket, aitril: AiTril, prompt: str):
     })
 
 
+async def handle_deployment(websocket: WebSocket, target: str):
+    """Handle deployment to selected target."""
+    deployment_info = {
+        "local": {
+            "name": "Local File System",
+            "description": "Files will be saved to your current directory",
+            "action": "save_files"
+        },
+        "docker": {
+            "name": "Docker Container",
+            "description": "Building Docker container with your code",
+            "action": "build_docker"
+        },
+        "github": {
+            "name": "GitHub Pages",
+            "description": "Deploying to GitHub Pages (requires GitHub repo)",
+            "action": "deploy_github"
+        },
+        "ec2": {
+            "name": "AWS EC2",
+            "description": "Deploying to EC2 instance (requires AWS credentials)",
+            "action": "deploy_ec2"
+        },
+        "skip": {
+            "name": "Skip Deployment",
+            "description": "Code generation complete - no deployment",
+            "action": "skip"
+        }
+    }
+
+    info = deployment_info.get(target, deployment_info["skip"])
+
+    # Send acknowledgment
+    await manager.send_event(websocket, {
+        "type": "deployment_started",
+        "target": target,
+        "name": info["name"],
+        "timestamp": datetime.now().isoformat()
+    })
+
+    # For now, just send a completion message
+    # In the future, this would actually perform the deployment
+    if target == "skip":
+        await manager.send_event(websocket, {
+            "type": "status_message",
+            "message": "✅ Build complete! Code is ready to use.",
+            "timestamp": datetime.now().isoformat()
+        })
+    else:
+        await manager.send_event(websocket, {
+            "type": "status_message",
+            "message": f"🚀 Deployment to {info['name']} initiated! (Implementation coming soon)",
+            "timestamp": datetime.now().isoformat()
+        })
+
+    # Send deployment completed event
+    await manager.send_event(websocket, {
+        "type": "deployment_completed",
+        "target": target,
+        "status": "acknowledged",
+        "timestamp": datetime.now().isoformat()
+    })
+
+
+# Settings API endpoints
+@app.get("/api/settings")
+async def get_settings():
+    """Get all settings (excluding sensitive data)."""
+    return settings_manager.export_settings()
+
+
+@app.get("/api/settings/providers")
+async def get_providers():
+    """Get all LLM provider configurations."""
+    return settings_manager.get_llm_providers()
+
+
+@app.get("/api/settings/providers/enabled")
+async def get_enabled_providers():
+    """Get list of enabled provider IDs."""
+    return {"providers": settings_manager.get_enabled_providers()}
+
+
+@app.put("/api/settings/providers/{provider_id}")
+async def update_provider(provider_id: str, config: Dict[str, Any]):
+    """Update LLM provider configuration."""
+    success = settings_manager.update_provider(provider_id, config)
+    if success:
+        return {"status": "success", "provider_id": provider_id}
+    else:
+        return {"status": "error", "message": "Failed to update provider"}
+
+
+@app.post("/api/settings/providers/custom")
+async def add_custom_provider(
+    provider_id: str,
+    name: str,
+    api_key_env: str,
+    model: str,
+    base_url: str
+):
+    """Add a custom LLM provider."""
+    success = settings_manager.add_custom_provider(
+        provider_id, name, api_key_env, model, base_url
+    )
+    if success:
+        return {"status": "success", "provider_id": provider_id}
+    else:
+        return {"status": "error", "message": "Failed to add custom provider"}
+
+
+@app.get("/api/settings/deployments")
+async def get_deployment_targets():
+    """Get all deployment target configurations."""
+    return settings_manager.get_deployment_targets()
+
+
+@app.get("/api/settings/deployments/enabled")
+async def get_enabled_deployments():
+    """Get list of enabled deployment target IDs."""
+    return {"targets": settings_manager.get_enabled_targets()}
+
+
+@app.put("/api/settings/deployments/{target_id}")
+async def update_deployment_target(target_id: str, config: Dict[str, Any]):
+    """Update deployment target configuration."""
+    success = settings_manager.update_deployment_target(target_id, config)
+    if success:
+        return {"status": "success", "target_id": target_id}
+    else:
+        return {"status": "error", "message": "Failed to update deployment target"}
+
+
+@app.get("/api/settings/general")
+async def get_general_settings():
+    """Get general application settings."""
+    return settings_manager.get_general_settings()
+
+
+@app.put("/api/settings/general")
+async def update_general_settings(config: Dict[str, Any]):
+    """Update general application settings."""
+    success = settings_manager.update_general_settings(config)
+    if success:
+        return {"status": "success"}
+    else:
+        return {"status": "error", "message": "Failed to update general settings"}
+
+
 @app.get("/health")
 async def health_check():
     """Health check endpoint."""
